==> nextcloud-22.2.6.tgz: nextcloud/apps/support/l10n/es_AR.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Contraseña:",
    "Generating system report failed." : "La generación del informe del sistema falló.",
    "Could not create folder \"System information\" to store generated report." : "No se pudo crear la carpeta \"Información del sistema\" para almacenar el informe generado.",
    "Subscription notifications" : "Notificaciones de suscripción",
    "Nextcloud Subscription" : "Suscripción a Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Su servidor no tiene una suscripción a Nextcloud o su suscripción ha caducado.",
    "Your Nextcloud server subscription does not cover your number of users." : "Su suscripción al servidor de Nextcloud no cubre su número de usuarios.",
    "Your Nextcloud Subscription has expired!" : "Tu suscripción a Nextcloud ha expirado!",
    "Your server has no Nextcloud Subscription" : "Su servidor no tiene suscripción a Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Su servidor de Nextcloud no está respaldado por una suscripción de Nextcloud Enterprise.",
    "Learn more now" : "Aprende más ahora",
    "Your Nextcloud server Subscription is over limit" : "Su suscripción al servidor Nextcloud está por encima del límite",
    "Dear admin," : "Estimado administrador,",
    "Thank you," : "Gracias,",
    "Your Nextcloud team" : "Tu equipo de Nextcloud",
    "Your Nextcloud server Subscription is expired" : "Su suscripción al servidor Nextcloud ha caducado",
    "Your Nextcloud server Subscription is expired!" : "Su suscripción al servidor Nextcloud ha caducado!",
    "Support" : "Soporte",
    "Getting support and help for your Nextcloud" : "Obteniendo soporte y ayuda para tu Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "La aplicación de soporte lo cubre con acceso directo a recursos de ayuda y consulta, opciones de contacto dedicadas al administrador de su cuenta y una descripción general de su suscripción empresarial.",
    "Basic subscription" : "Suscripción básica",
    "Standard subscription" : "Suscripción estándar",
    "Premium subscription" : "Suscripción premium",
    "Géant subscription" : "Suscripción gigante",
    "Silver partner subscription" : "Suscripción de plata",
    "Gold partner subscription" : "Suscripción de oro",
    "Subscription" : "Suscripción",
    "Valid subscription" : "Suscripción válida",
    "Expired subscription" : "Suscripción expirada",
    "Subscription key:" : "Clave de suscripción:",
    "Update subscription key" : "Actualizar la clave de suscripción",
    "You can find answers to common question in our portal and also file support requests there." : "Puede encontrar respuestas a preguntas comunes en nuestro portal y también presentar solicitudes de soporte allí.",
    "System information" : "Información del sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Recopilar información del sistema para casos de soporte. El siguiente botón genera un archivo de texto en la carpeta \"Información del sistema\" y lo comparte como un enlace público protegido por contraseña. El enlace es válido por 2 semanas.",
    "Generate system report" : "Generar informe del sistema",
    "Enterprise subscription recommended" : "Suscripción de empresa recomendada",
    "No active enterprise subscription" : "Ninguna suscripción de empresa activa",
    "Unsupported" : "No soportado",
    "This Nextcloud server has no Enterprise Subscription." : "Este servidor de Nextcloud no tiene suscripción a la empresa.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Una suscripción a Nextcloud Enterprise lo ayuda a aprovechar al máximo su Nextcloud, mantener sus datos seguros y su servidor funcionando de manera confiable en todo momento.",
    "Advantages" : "Ventajas",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Acceso a la experiencia técnica de los desarrolladores de Nextcloud a través de la documentación y el soporte",
    "Access to additional capabilities like Outlook integration, online office and more" : "Acceso a capacidades adicionales como integración de Outlook, oficina en línea y más",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Acceso a la experiencia de escalabilidad y capacidades de escalabilidad para Files and Talk",
    "Optional branding, consulting, architecture advice" : "Opcional branding, consultoría, asesoramiento en arquitectura.",
    "Confidential security notification service, mitigations, patches and advice" : "Servicio confidencial de notificación de seguridad, mitigaciones, parches y asesoramiento.",
    "Compliance certification, advice and documentation" : "Certificación de cumplimiento, asesoramiento y documentación.",
    "Get a quote" : "Consigue una cotización",
    "More information" : "Más información",
    "Subscription benefits" : "Beneficios de suscripción",
    "Pricing" : "Precios",
    "Forum" : "Foro",
    "GitHub" : "GitHub",
    "Chat" : "Chat",
    "Nextcloud forum" : "Foro de Nextcloud",
    "Subscription key" : "Clave de suscripción",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Si tiene una suscripción activa a Nextcloud, ingrese su clave de suscripción aquí.",
    "Learn more about an enterprise subscription." : "Obtenga más información sobre una suscripción empresarial.",
    "Set subscription key" : "Establecer clave de suscripción",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "La información de suscripción no se pudo recuperar correctamente en este momento. Está programado un reintento. Por favor, vuelva más tarde.",
    "The subscription key was invalid." : "La clave de suscripción no es válida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "La clave de suscripción no se pudo verificar porque este servidor no tiene conexión a Internet. Por favor, comuníquese con el equipo de soporte para resolver esto.",
    "The subscription key had an invalid format." : "La clave de suscripción tenía un formato no válido.",
    "While fetching the subscription information an error happened." : "Al recuperar la información de suscripción, ocurrió un error.",
    "News" : "Noticias",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Para obtener información actualizada sobre lo que está pasando en Nextcloud, suscríbase al boletín y síganos en nuestras cuentas de redes sociales.",
    "Like our Facebook page" : "Me gusta en nuestra página de Facebook",
    "Follow us on Twitter" : "Síguenos en Twitter",
    "Check out our blog" : "Echa un vistazo a nuestro blog.",
    "Subscribe to our newsletter" : "Suscríbete a nuestro boletín"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/support/l10n/es_AR.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Contraseña:",
    "Generating system report failed." : "La generación del informe del sistema falló.",
    "Could not create folder \"System information\" to store generated report." : "No se pudo crear la carpeta \"Información del sistema\" para almacenar el informe generado.",
    "Subscription notifications" : "Notificaciones de suscripción",
    "Nextcloud Subscription" : "Suscripción a Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Su servidor no tiene una suscripción a Nextcloud o su suscripción ha caducado.",
    "Your Nextcloud server subscription does not cover your number of users." : "Su suscripción al servidor de Nextcloud no cubre su número de usuarios.",
    "Your Nextcloud Subscription has expired!" : "Tu suscripción a Nextcloud ha expirado!",
    "Your server has no Nextcloud Subscription" : "Su servidor no tiene suscripción a Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Su servidor de Nextcloud no está respaldado por una suscripción de Nextcloud Enterprise.",
    "Learn more now" : "Aprende más ahora",
    "Your Nextcloud server Subscription is over limit" : "Su suscripción al servidor Nextcloud está por encima del límite",
    "Dear admin," : "Estimado administrador,",
    "Thank you," : "Gracias,",
    "Your Nextcloud team" : "Tu equipo de Nextcloud",
    "Your Nextcloud server Subscription is expired" : "Su suscripción al servidor Nextcloud ha caducado",
    "Your Nextcloud server Subscription is expired!" : "Su suscripción al servidor Nextcloud ha caducado!",
    "Support" : "Soporte",
    "Getting support and help for your Nextcloud" : "Obteniendo soporte y ayuda para tu Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "La aplicación de soporte lo cubre con acceso directo a recursos de ayuda y consulta, opciones de contacto dedicadas al administrador de su cuenta y una descripción general de su suscripción empresarial.",
    "Basic subscription" : "Suscripción básica",
    "Standard subscription" : "Suscripción estándar",
    "Premium subscription" : "Suscripción premium",
    "Géant subscription" : "Suscripción gigante",
    "Silver partner subscription" : "Suscripción de plata",
    "Gold partner subscription" : "Suscripción de oro",
    "Subscription" : "Suscripción",
    "Valid subscription" : "Suscripción válida",
    "Expired subscription" : "Suscripción expirada",
    "Subscription key:" : "Clave de suscripción:",
    "Update subscription key" : "Actualizar la clave de suscripción",
    "You can find answers to common question in our portal and also file support requests there." : "Puede encontrar respuestas a preguntas comunes en nuestro portal y también presentar solicitudes de soporte allí.",
    "System information" : "Información del sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Recopilar información del sistema para casos de soporte. El siguiente botón genera un archivo de texto en la carpeta \"Información del sistema\" y lo comparte como un enlace público protegido por contraseña. El enlace es válido por 2 semanas.",
    "Generate system report" : "Generar informe del sistema",
    "Enterprise subscription recommended" : "Suscripción de empresa recomendada",
    "No active enterprise subscription" : "Ninguna suscripción de empresa activa",
    "Unsupported" : "No soportado",
    "This Nextcloud server has no Enterprise Subscription." : "Este servidor de Nextcloud no tiene suscripción a la empresa.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Una suscripción a Nextcloud Enterprise lo ayuda a aprovechar al máximo su Nextcloud, mantener sus datos seguros y su servidor funcionando de manera confiable en todo momento.",
    "Advantages" : "Ventajas",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Acceso a la experiencia técnica de los desarrolladores de Nextcloud a través de la documentación y el soporte",
    "Access to additional capabilities like Outlook integration, online office and more" : "Acceso a capacidades adicionales como integración de Outlook, oficina en línea y más",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Acceso a la experiencia de escalabilidad y capacidades de escalabilidad para Files and Talk",
    "Optional branding, consulting, architecture advice" : "Opcional branding, consultoría, asesoramiento en arquitectura.",
    "Confidential security notification service, mitigations, patches and advice" : "Servicio confidencial de notificación de seguridad, mitigaciones, parches y asesoramiento.",
    "Compliance certification, advice and documentation" : "Certificación de cumplimiento, asesoramiento y documentación.",
    "Get a quote" : "Consigue una cotización",
    "More information" : "Más información",
    "Subscription benefits" : "Beneficios de suscripción",
    "Pricing" : "Precios",
    "Forum" : "Foro",
    "Nextcloud forum" : "Foro de Nextcloud",
    "GitHub" : "GitHub",
    "Subscription key" : "Clave de suscripción",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Si tiene una suscripción activa a Nextcloud, ingrese su clave de suscripción aquí.",
    "Learn more about an enterprise subscription." : "Obtenga más información sobre una suscripción empresarial.",
    "Set subscription key" : "Establecer clave de suscripción",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "La información de suscripción no se pudo recuperar correctamente en este momento. Está programado un reintento. Por favor, vuelva más tarde.",
    "The subscription key was invalid." : "La clave de suscripción no es válida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "La clave de suscripción no se pudo verificar porque este servidor no tiene conexión a Internet. Por favor, comuníquese con el equipo de soporte para resolver esto.",
    "The subscription key had an invalid format." : "La clave de suscripción tenía un formato no válido.",
    "While fetching the subscription information an error happened." : "Al recuperar la información de suscripción, ocurrió un error.",
    "News" : "Noticias",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Para obtener información actualizada sobre lo que está pasando en Nextcloud, suscríbase al boletín y síganos en nuestras cuentas de redes sociales.",
    "Like our Facebook page" : "Me gusta en nuestra página de Facebook",
    "Follow us on Twitter" : "Síguenos en Twitter",
    "Check out our blog" : "Echa un vistazo a nuestro blog.",
    "Subscribe to our newsletter" : "Suscríbete a nuestro boletín"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
